@@ -13,6 +13,8 @@
 
 #![feature(cfg_target_vendor)]
 #![feature(link_cfg)]
+#![cfg_attr(not(stage0), feature(nll))]
+#![cfg_attr(not(stage0), feature(infer_outlives_requirements))]
 #![feature(staged_api)]
 #![feature(unwind_attributes)]
 #![feature(static_nobundle)]
